@@ -64,7 +64,10 @@ def datachange_trigger(model, instance, type):
                     for field in fields
                 ):
                     continue
-            if trigger.filter.queryset.filter(pk=instance.pk).exists():
+            if (
+                trigger.action
+                and trigger.filter.queryset.filter(pk=instance.pk).exists()
+            ):
                 # delay execution a bit as the trigger may run immediately even though
                 # the current request has not finished (and therefore not commited to DB yet)
                 run_action.apply_async(
@@ -77,13 +80,15 @@ def periodic_trigger():
 
     from .models import DateFieldTrigger
 
+    print(f"Trigger-range: {timezone.now()} - {timezone.now() + TRIGGER_PERIOD}")
     for trigger in DateFieldTrigger.objects.filter(enable=True):
         for instance in trigger.filter.queryset.all():
-            td = trigger.triggerdate(instance)
-            if (
-                td is not None
-                and timezone.now() <= td < timezone.now() + TRIGGER_PERIOD
-            ):
-                run_action.apply_async(
-                    (trigger.action.pk, instance._meta.label, instance.pk)
-                )
+            for td in trigger.triggerdates(instance):
+                print(td)
+                if (
+                    td is not None
+                    and timezone.now() <= td < timezone.now() + TRIGGER_PERIOD
+                ) and trigger.action:
+                    run_action.apply_async(
+                        (trigger.action.pk, instance._meta.label, instance.pk)
+                    )
